==> org.eclipse.lsp4j.debug_0.8.1.v20190925-0746.jar: org/eclipse/lsp4j/debug/SetDataBreakpointsArguments.java <==
/**
 * Copyright (c) 2017, 2018 Kichwa Coders Ltd. and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j.debug;

import java.util.Arrays;
import org.eclipse.lsp4j.debug.DataBreakpoint;
import org.eclipse.lsp4j.debug.util.Preconditions;
import org.eclipse.lsp4j.jsonrpc.validation.NonNull;
import org.eclipse.xtext.xbase.lib.Pure;
import org.eclipse.xtext.xbase.lib.util.ToStringBuilder;

/**
 * Arguments for 'setDataBreakpoints' request.
 */
@SuppressWarnings("all")
public class SetDataBreakpointsArguments {
  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  @NonNull
  private DataBreakpoint[] breakpoints;
  
  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  @Pure
  @NonNull
  public DataBreakpoint[] getBreakpoints() {
    return this.breakpoints;
  }
  
  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  public void setBreakpoints(@NonNull final DataBreakpoint[] breakpoints) {
    this.breakpoints = Preconditions.checkNotNull(breakpoints, "breakpoints");
  }
  
  @Override
  @Pure
  public String toString() {
    ToStringBuilder b = new ToStringBuilder(this);
    b.add("breakpoints", this.breakpoints);
    return b.toString();
  }
  
  @Override
  @Pure
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    SetDataBreakpointsArguments other = (SetDataBreakpointsArguments) obj;
    if (this.breakpoints == null) {
      if (other.breakpoints != null)
        return false;
    } else if (!Arrays.deepEquals(this.breakpoints, other.breakpoints))
      return false;
    return true;
  }
  
  @Override
  @Pure
  public int hashCode() {
    return 31 * 1 + ((this.breakpoints== null) ? 0 : Arrays.deepHashCode(this.breakpoints));
  }
}

==> org.eclipse.lsp4j.debug_0.20.0.v20230213-1727.jar: org/eclipse/lsp4j/debug/SetDataBreakpointsArguments.java <==
/**
 * Copyright (c) 2017, 2020 Kichwa Coders Ltd. and others.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0,
 * or the Eclipse Distribution License v. 1.0 which is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 * 
 * SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 */
package org.eclipse.lsp4j.debug;

import com.google.common.base.MoreObjects;
import java.util.Arrays;
import org.eclipse.lsp4j.debug.util.Preconditions;
import org.eclipse.lsp4j.jsonrpc.validation.NonNull;

/**
 * Arguments for 'setDataBreakpoints' request.
 */
@SuppressWarnings("all")
public class SetDataBreakpointsArguments {
  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  @NonNull
  private DataBreakpoint[] breakpoints;

  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  @NonNull
  public DataBreakpoint[] getBreakpoints() {
    return this.breakpoints;
  }

  /**
   * The contents of this array replaces all existing data breakpoints. An empty array clears all data breakpoints.
   */
  public void setBreakpoints(@NonNull final DataBreakpoint[] breakpoints) {
    this.breakpoints = Preconditions.checkNotNull(breakpoints, "breakpoints");
  }

  @Override
  public String toString() {
    MoreObjects.ToStringHelper b = MoreObjects.toStringHelper(this);
    b.add("breakpoints", this.breakpoints);
    return b.toString();
  }

  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
      return true;
    if (obj == null)
      return false;
    if (getClass() != obj.getClass())
      return false;
    SetDataBreakpointsArguments other = (SetDataBreakpointsArguments) obj;
    if (this.breakpoints == null) {
      if (other.breakpoints != null)
        return false;
    } else if (!Arrays.deepEquals(this.breakpoints, other.breakpoints))
      return false;
    return true;
  }

  @Override
  public int hashCode() {
    return 31 * 1 + ((this.breakpoints== null) ? 0 : Arrays.deepHashCode(this.breakpoints));
  }
}
